Crate rust_releases_channel_manifests

Crate rust_releases_channel_manifests 

Please, see the rust-releases for additional documentation on how this crate can be used.

Structs

ChannelManifestsDeprecated
A Source which parses Rust release data from channel manifests, which used to be published for each release. Since 2020-02-23, however, no more channel manifests have been published.

Enums

ChannelManifestsError
Top level failure cases for rust-releases-channel-manifests source crate

Type Aliases

ChannelManifestsResult
A result type which binds the ChannelManifestsError to the error type.