Please, see the rust-releases for additional documentation on how this crate can be used.
Structs
- Channel
Manifests Deprecated - A
Sourcewhich parses Rust release data from channel manifests, which used to be published for each release. Since 2020-02-23, however, no more channel manifests have been published.
Enums
- Channel
Manifests Error - Top level failure cases for rust-releases-channel-manifests source crate
Type Aliases
- Channel
Manifests Result - A result type which binds the
ChannelManifestsErrorto the error type.